@@ -2,7 +2,7 @@
  * socket.c -- socket library functions
  *
  * Copyright 1998 - 2004 by Eric S. Raymond.
- * Copyright 2004 - 2020 by Matthias Andree.
+ * Copyright 2004 - 2023 by Matthias Andree.
  * Contributions by Alexander Bluhm, Earl Chew, John Beck.
 
  * For license terms, see the file COPYING in this directory.
@@ -405,8 +405,6 @@ va_dcl {
 #include <openssl/x509v3.h>
 #include <openssl/rand.h>
 
-#define fm_MIN_OPENSSL_VER 0x1000206fL /* 1.0.2f */
-
 #ifdef LIBRESSL_VERSION_NUMBER 
 # ifdef __OpenBSD__
 #  pragma message "WARNING - Linking against LibreSSL, which is not a supported configuration."
@@ -416,13 +414,22 @@ va_dcl {
 #endif
 
 #ifdef USING_WOLFSSL
-# if LIBWOLFSSL_VERSION_HEX < 0x05001001L
-#  error "FAILED - wolfSSL 5.1.1 or newer required."
+# if LIBWOLFSSL_VERSION_HEX < 0x05005001L
+#  error "FAILED - wolfSSL MUST be at least version 5.5.1. You have " LIBWOLFSSL_VERSION_STRING "."
 # endif
-#else /* USING_WOLFSSL */
-# if OPENSSL_VERSION_NUMBER < 0x1010100fL
-#  pragma message "WARNING - OpenSSL SHOULD be at least version 1.1.1."
+# if LIBWOLFSSL_VERSION_HEX < 0x05005003L
+#  pragma message "WARNING - wolfSSL SHOULD be at least version 5.5.3. You have " LIBWOLFSSL_VERSION_STRING "."
 # endif
+#else /* !USING_WOLFSSL */
+#define fm_MIN_OPENSSL_VER 0x1000206fL /* 1.0.2f */
+# if OPENSSL_VERSION_NUMBER <  0x1010111fL
+#  pragma message "WARNING - OpenSSL 1.m.nx SHOULD be at least release version 1.1.1q, using " OPENSSL_VERSION_TEXT "."
+# endif                     /* 0xMNN00PPSL */
+# if OPENSSL_VERSION_NUMBER >= 0x30000000L
+#  if OPENSSL_VERSION_NUMBER < 0x30000070L
+#   pragma message "WARNING - OpenSSL 3.m.n SHOULD be at least release version 3.0.7, using " OPENSSL_VERSION_TEXT "."
+#  endif
+# endif                     /* 0xMNN00PPSL */
 # if OPENSSL_VERSION_NUMBER < fm_MIN_OPENSSL_VER
 #  error Your OpenSSL version must be at least 1.0.2f release. Older OpenSSL versions are unsupported.
 # else /* OpenSSL too old */
@@ -1109,6 +1116,12 @@ int SSLOpen(int sock, char *mycert, char *mykey, const char *myproto, int certck
 		if (*tmp) wolfSSL_Debugging_ON();
 	    }
 	}
+	{
+		int wver = wolfSSL_lib_version_hex();
+		if (wver < LIBWOLFSSL_VERSION_HEX) {
+		    report(stderr, GT_("Loaded wolfSSL library %#lx older than headers %#lx, refusing to work.\n"), (long)wver, (long)(LIBWOLFSSL_VERSION_HEX));
+		}
+	}
 #endif
 
 	if (ver < OPENSSL_VERSION_NUMBER) {
